function [ S ] = calc_metrics(Y,verbose);
% Calculate the summary metrics of the discharge data

% If only one input argument --> no printing to screen
if nargin == 1, verbose = 0; end

% Store local variables in memory
persistent P n_Y phi cdf n_cdf P_min n_days

% Load the data and define local variables - only once
if isempty(P),
    
    % Load the French Broad data
    daily_data = load('03451500.dly');
    
    % Define the measured precipitation (two year spin up for mode)
    P = daily_data(731:end,4);
    
    % How many streamflow data points?
    n_Y = numel(Y); 
    
    % Value for low pass filter (baseflow index calculation)
    phi = 0.925;
    
    % Define ranges for recession analysis - and number of ranges
    cdf = [ 0 1/2 1 ]; n_cdf = numel ( cdf );
    
    % mm --> those days are considered without rainfall
    P_min = 1/2; 
    
    % How many previous days at least without rainfall
    n_days = 3;

end

% Initialize S to be empty (so that it is always a horizontal vector
S = nan(1,2);

% ------------------ S1 : Runoff ratio ------------------ %
S(1) = sum(Y)/sum(P);
% ------------------------------------------------------- %

% ----------------- S2 : Baseflow index ----------------- %
yb(1) = 0.25 * Y(1);
% Now loop using low pass filter
for j = 2 : n_Y,
    yb(j,1) = min ( phi * yb(j-1,1) + 1/2 * (1 - phi) * ( Y(j,1) + Y(j-1,1) ) , Y(j,1) );
end
% Now calculate the annual baseflow coefficient
S(2) = sum(yb)/sum(Y);
% ------------------------------------------------------- %

% ------------- S3/S4 : Flow duration curve ------------- %
x = [ 1 1 ];
% Calculate exceedance probability
[ Y_sort , E_prob ] = calc_FDC( Y(:) , n_Y );
% Fit the FDC using van Genuchten model
S(3:4) = fminsearch(@(x) VG_Ret(x,Y_sort,E_prob,n_Y),x);

% ------------------------------------------------------- %