% ---------------------------- Check the following 4 papers ------------------------------- %
%                                                                                           %
%   Vrugt, J.A., and M. Sadegh (2014), Diagnostic Bayes: Sufficient statistics, Water       %
%       Resources Research, In preparation.                                                 %
%   Lochbuhler, T., J.A. Vrugt, M. Sadegh, and N. Linde (2014), Summary statistics from     %
%       training images as prior information in probabilistic inversion, Geophysical        %
%       Journal International, 201, 157-171, doi:10.1093/gji/ggv008.                        %
%   Sadegh, M., and J.A. Vrugt (2014), Approximate Bayesian computation using Markov chain  %
%       Monte Carlo simulation: DREAM_(ABC), Water Resources Research,                      %
%       doi:10.1002/2014WR015386.                                                           %
%   Vrugt, J.A., and M. Sadegh (2013), Toward diagnostic model calibration and evaluation:  %
%       Approximate Bayesian computation, Water Resources Research, 49, 43354345,          %
%       doi:10.1002/wrcr.20354.                                                             %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.d = 7;                         % Dimensionality of target
DREAMPar.T = 5000;                      % Number of generations
DREAMPar.lik = 11;                      % Model output is simulation: Gaussian likelihood

%% Provide information parameter space and initial sampling
Par_info.initial = 'latin';             % Latin hypercube sampling
Par_info.boundhandling = 'reflect';     % Explicit boundary handling

% parname:       Imax  Smax  Qsmax   alE   alF   Kfast  Kslow
Par_info.min = [ 0.5   10     0    1e-6   -10     0      0    ];    % If 'latin', min values
Par_info.max = [ 10   1000   100   100     10     10    150   ];    % If 'latin', max values

%% Define name of function (.m file) for posterior exploration
Func_name = 'rainfall_runoff';

%% Define the observed streamflow data
daily_data = load('03451500.dly'); Meas_info.Y = daily_data(731:end,6);

%% Now calculate summary metrics from the discharge data and define as prior distribution
[ Meas_info.S ] = calc_metrics( Meas_info.Y )';

%% Optional settings
options.DB = 'yes';                     % Diagnostic Bayes: ABC with summary metrics as prior
options.epsilon = [ 0.1 ];              % Epsilon of the noisy ABC implementation (illustration values)
options.parallel = 'yes';               % Run each chain on different core
options.modout = 'yes';                 % Store model simulations
options.save = 'yes';

%% Run the DREAM_ZS algorithm
[chain,output,fx] = DREAM_ZS(Func_name,DREAMPar,Par_info,Meas_info,options);