function [ log_L ] = BMA_calc ( x );
% This function calculates the log likelihood corresponding to the weights and sigma's

global BMA          % Request the BMA structure
L = 0;              % Set likelihood equivalent to zero
w = x(1:BMA.k);     % Unpack weights

switch lower(BMA.PDF)           % Now check which BMA model is used 
    
    case {'normal'}             % Normal distribution with homoscedastic error variance

        if strcmp(lower(BMA.VAR),'single');         % One or multiple variances?
            sigma = x(BMA.k+1) * ones(1,BMA.k);
        elseif strcmp(lower(BMA.VAR),'multiple');
            sigma = x(BMA.k + 1 : end);
        else
            error('do not know this option for variance treatment')
        end
        
        for i = 1:BMA.k,                            % Mixture model
            L = L + w(i)*exp(-1/2*((BMA.Ycal-BMA.Xcal(:,i))./sigma(i)).^2)./ ...
                (sqrt(2*pi).*sigma(i));             % Now calculate likelihood
        end
        
    case {'heteroscedastic'}    % Normal distribution with heteroscedastic error variance
                
        b = x(BMA.k+1);                             % Unpack variance parameter
        for i = 1:BMA.k,                            % Mixture model
            sigma = abs(b*BMA.Xcal(:,i));           % Calculate measurement error of data
            L = L + w(i)*exp(-1/2*((BMA.Ycal-BMA.Xcal(:,i))./sigma).^2)./ ...
                (sqrt(2*pi).*sigma);                % Calculate likelihood
        end
        
    case {'gamma'}              % Gamma distribution
        
        b = x(BMA.k+1:2*BMA.k); c = x(2*BMA.k+1);   % Unpack variables gamma distribution
        for i = 1:BMA.k,                            % Mixture model
            mu = abs(BMA.Xcal(:,i));                % Derive mean of gamma distribution
            var = abs(c + b(i) * BMA.Xcal(:,i));    % Derive variance of gamma distribution
            A = mu.^2./var; B = var./mu;            % Derive A and B of gamma distribution
            z = BMA.Ycal./B;                        % Compute help variable
            u = (A - 1).*log(z) - z - gammaln(A);   % Compute help variable
            L = L + w(i) * (exp(u)./B);             % Calculate likelihood
        end
        
end

L(L==0) = 1e-300;       % Replace zero likelihood with 1e-300       
log_L = sum(log(L));    % Now compute the log-likelihood of the BMA model