function [A,B,Xcal,Xval] = ComputeAB(Xcal,Ycal,Xval,reg);
% Function performs linear bias correction if indicated
%
% ------------------------------------------------------------------------- 
% Input:    Xcal    Calibration data set with model forecasts
%           Ycal    Calibration data set with observation targets
%           Xval    Valibration data set with model forecasts
%           reg     Do bias correction or not (TRUE or FALSE)
%
% Output:   A       Bias intercepts of the individual model forecasts
%           B       Bias slopes of the individual model forecasts
%           Xcal    Bias corrected model forecasts for calibration set
%           Xval    Bias corrected model forecasts for validation set
% -------------------------------------------------------------------------

k = size(Xcal,2);
if strcmp(reg.adjust,'TRUE');
    % Bias correction terms (linear regression)
    B = zeros(1,k); A = zeros(1,k);
    for i = 1:k,
        % Generate some temporarily variables
        T = cov(Xcal(:,i),Ycal); T = T(1,2); 
        % Calculate Slope
        B(i) = T/var(Xcal(:,i));
        % Calculate Intercept
        A(i) = mean(Ycal) - B(i) * mean(Xcal(:,i));
    end
else
    B = ones(1,k); A = zeros(1,k);
end

for qq = 1:k,
    Xcal(:,qq) = B(qq)*Xcal(:,qq) + A(qq);
    Xval(:,qq) = B(qq)*Xval(:,qq) + A(qq);
end