% ------------------------------ Check the following paper -------------------------------- %
%                                                                                           %
%   Vrugt, J.A. (2015), Markov chain Monte Carlo simulation using the DREAM software        %
%       package: Theory, concepts, and MATLAB implementation, Environmental Modeling and    %
%       Software, XX, XX, doi:XX/XX.                                                        %
%                                                                                           %
%   Vrugt, J.A., C.G.H. Diks, and M.P. Clark (2008), Ensemble Bayesian model averaging      %
%       using Markov chain Monte Carlo sampling, Environmental Fluid Mechanics, 8(5-6),     %
%       579-595, doi:10.1007/s10652-008-9106-3.                                             %
%   Vrugt, J.A., and B.A. Robinson (2007), Treatment of uncertainty using ensemble methods: %
%       Comparison of sequential data assimilation and Bayesian model averaging,            %
%       Water Resources Research, 43, W01411, doi:10.1029/2005WR004838.                     %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.T = 5000;      % Number of generations
DREAMPar.lik = 2;       % Model returns log-likelihood

%% Initial sampling and parameter ranges
Par_info.initial = 'latin';         % Latin hypercube sampling
Par_info.boundhandling = 'reflect'; % Explicit boundary handling

%% Define name of function (.m file) for posterior exploration
Func_name = 'BMA_calc'; global BMA

%% Load data from Vrugt and Robinson, WRR, 43, W01411, doi:10.1029/2005WR004838, 2007
load data.txt;              % Daily streamflow simulations eight watershed models
load Y.txt;                 % Daily streamflow observations
StartT = 1; EndT = 3000;    % Start/End day training period
BMA.PDF = 'normal';          % pdf predictor: normal/heteroscedastic/gamma
BMA.VAR = 'multiple';       % variance pdf: single/multiple (multiple for 'normal')

%% Setup the BMA model (apply linear bias correction)
[DREAMPar,BMA,Par_info] = setup_BMA(DREAMPar,Par_info,BMA,data,Y,StartT,EndT);

%% Run the DREAM_ZS algorithm
[chain,output,fx,Z] = DREAM_ZS(Func_name,DREAMPar,Par_info);
