function [DREAMPar,BMA,Par_info] = setup_BMA(DREAMPar,Par_info,BMA,data,Y,StartT,EndT);
% --------------------------- WHICH DISTRIBUTION FOR CONDITIONAL PDF? ------------------------- %

% Define the number of different models
BMA.k = size(data,2);

% Do we do a linear bias correction of the predictors or not?
reg.adjust = 'TRUE';

% Define calibration and validation set (X are forecasts; Y = observations)
Xcal = data(StartT:EndT,1:BMA.k); BMA.Ycal = Y(StartT:EndT,1);

% Now assign the evaluation data (remaining part of data)
Xval = data(EndT+1:end,1:BMA.k); BMA.Yval = Y(EndT+1:end,1);

% Do bias correction
[BIASa,BIASb,BMA.Xcal,BMA.Xval] = ComputeAB(Xcal,BMA.Ycal,Xval,reg);

% How many chains?
DREAMPar.d = BMA.k + 2;

BMA.PDF = lower(BMA.PDF); BMA.VAR = lower(BMA.VAR);

% Provide parameter ranges
switch BMA.PDF
    
    case 'normal'               % Normal distribution with homoscedastic error
        
        switch BMA.VAR
            
            case 'single'
                
                Par_info.min = zeros(1,BMA.k+1); Par_info.max = [ ones(1,BMA.k) 2*std( BMA.Ycal )];

            case 'multiple'
                
                Par_info.min = zeros(1,2*BMA.k); Par_info.max = [ ones(1,BMA.k) 2*std( BMA.Ycal )*ones(1,BMA.k) ];
                
        end
        
    case {'heteroscedastic'}    % Normal distribution with heteroscedastic error variance
        
        Par_info.min = zeros(1,BMA.k+1); Par_info.max = [ ones(1,BMA.k) 2*std( BMA.Ycal )];
        
    case 'gamma'                % Gamma pdf with heteroscedastic error
    
        Par_info.min = zeros(1,2*BMA.k+1); Par_info.max = [ ones(1,BMA.k) 10 * ones(1,BMA.k) mean(BMA.Ycal) ];
   
    otherwise
        
        error('do not know this distribution');
        
end

% How many parameters?
DREAMPar.d = size(Par_info.min,2); 