% ----------------------------------------------------------------------------------------- %
%                                                                                           %
%            ANALYTIC SOLUTION OF HEAT FLOW EQUATION: WRITTEN BY J.A. VRUGT                 %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.d = 4;         % Dimension of the problem
DREAMPar.T = 5000;      % Number of generations
DREAMPar.lik = 23;      % Likelihood 23 (limits of acceptability)

%% Initial sampling and parameter ranges
Par_info.initial = 'latin';         % Latin hypercube sampling
Par_info.boundhandling = 'reflect'; % Explicit boundary handling: reflection
Par_info.min = [ 10  0   0    0  ]; % Lower bound parameters
Par_info.max = [ 30  10  24   50 ]; % Upper bound parameters

%% Define name of function (.m file) for posterior exploration
Func_name = 'heat_flow';

%% Load calibration data vector (summary metrics with which simulations are compared)
Meas_info.S = load('temp_data.txt');  % Temperature data are summary statistics

%% Optional settings (limits of acceptability)
options.epsilon = 2;
options.modout = 'yes';

%% Run the DREAM_ZS algorithm
[chain,output,fx,Z] = DREAM_ZS(Func_name,DREAMPar,Par_info,Meas_info,options);
