function [ soil_temp ] = heat_flow ( x )
% Calculates the soil temperature at depth z and time t

persistent z omega t            % Retain structure data in memory after first call

if isempty(z),
    %% Define depth of simulation, omega and time of calculation
    z = [ 5 10 15]; omega = 2*pi/24; t = [1:1:48]; 
end

T_surf = x(1); A0 = x(2); phi = x(3); d = x(4);  % Unpack parameter values

for i = 1:3
    soil_temp(:,i) = T_surf + A0*exp(-z(i)/d).*sin(omega*(t-phi) - z(i)/d);
end

%% Return soil_temp as a single vector
soil_temp = soil_temp(:);