% -------------------------------- Check the following paper ------------------------------ %
%                                                                                           %
%   Scharnagl, B., J.A. Vrugt, H. Vereecken, and M. Herbst (2011), Bayesian inverse         %
%	    modeling of soil water dynamics at the field scale: using prior information         %
%	    on soil hydraulic properties, Hydrology and Earth System Sciences, 15, 30433059,   %
%       doi:10.5194/hess-15-3043-2011.                                                      %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.d = 6;                         % Dimension of the problem
DREAMPar.T = 500;                       % Number of generations
DREAMPar.lik = 23;                      % Limits of acceptability likelihood

%% Provide information parameter space and initial sampling
Par_info.initial = 'latin';             % Initial sample from Latin hypercube sampling
Par_info.boundhandling = 'reflect';     % Explicit boundary handling
%				1		2		3		4		 5		 6
%				[thetar	thetas	alpha	n	     Ks     h_bot
Par_info.min =	[0.0    0.30	0.02	1.05	0.01   -500];   % If "latin"
Par_info.max =	[0.1    0.55	0.50	2.50	100/24 -10];    % If "latin"

%% Define name of function (.m file) for posterior exploration
Func_name = 'HYDRUS';

%% Now load the data to define the measured data
data = xlsread('all_observations.xlsx','TDR_data','A4:AG64'); data = data(:,[4 6:end]);
%% Now derive the mean soil moisture value at 6 cm depth
for i = 1:size(data,2),
    temp = data(:,i); temp = sort ( temp(~isnan(temp) ) ); N = numel(temp);
    % Mean soil moisture at time t as observed summary metrics
    Meas_info.S(i,1) = mean ( temp );
    % We also want to derive the limits of acceptability - 95% range
    r(i,1:2) = [ temp(round(0.025*N)); temp(round(0.975*N))];
end

%% Optional settings
options.IO = 'yes';                     % Input-output writing of model files (only for parallel!)
options.parallel = 'yes';               % Run chains in parallel
options.epsilon = .5*diff(r,[],2);      % Define the LOAs
options.save = 'yes';
options.modout = 'yes';

%% Run the DREAM_ZS algorithm
[chain,output,fx,Z] = DREAM_ZS(Func_name,DREAMPar,Par_info,Meas_info,options);