function [ SimRR ] = NC_model(x);
% Nash-Cascade unit hydrograph -- series of three linear reservoirs

% Store local variables in memory
persistent Time maxT P

if isempty(Time),
    
    % Define maximum time
    maxT = 25;
    % Define the precipitation
    P = [ 10 25 8 2 zeros(1,21) ]';
    % Define Time
    Time = [ 1 : maxT ];
    
end

% Unpack parameter values (recession constant, number of reservoirs)
k = x(1); n = x(2);

% -------------------------------------------------------------------------
%                           Model script
% -------------------------------------------------------------------------

if k < 1,
    % Write to screen
    disp('Recession constant < 1 day --> numerical errors possible')
end;

% Define help matrix
A = zeros(maxT,maxT);

% Calculate unit hydrograph
IUH = 1 / ( k * gamma(n) )  * ( Time / k ).^(n-1) .* exp( -Time / k );

% Now loop over time
for t = 1 : maxT,
    
    % Define idx
    idx = [ 1 : maxT - (t - 1) ];
    
    % Calculate flow
    A(t,t:maxT) = P(t) * IUH(idx);
    
end

% Now determine total flow
SimRR = sum(A)';