% ---------------------------- Check the following 3 papers ------------------------------- %
%                                                                                           %
%   Nash, J.E. (1960), A unit hydrograph study with particular reference to British         %
%       catchments, Proceedings - Institution of Civil Engineers, 17, 249-282      .        %
%   Nash, J.E., J.V. Sutcliffe (1970), River flow forecasting through conceptual models     %
%       part I - A discussion of principles, Journal of Hydrology, 10(3), 282-290.          %
%   Beven, K.J., and A.M. Binley (1992), The future of distributed models: Model            %
%       calibration and uncertainty prediction. Hydrological Processes, 6, 279298,         %
%       doi: 10.1002/hyp.3360060305.                                                        %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.d = 2;                         % Dimension of the problem
DREAMPar.T = 1000;                      % Number of generations
DREAMPar.lik = 23;                      % Limits of acceptability likelihood

%% Provide information parameter space and initial sampling
Par_info.initial = 'latin';             % Latin hypercube sampling
Par_info.boundhandling = 'reflect';     % Explicit boundary handling
Par_info.min = [ 1   1  ];              % If 'latin', min values
Par_info.max = [ 10  10 ];              % If 'latin', max values

%% Define name of function (.m file) for posterior exploration
Func_name = 'NC_model';

%% Create the synthetic time series
[S] = NC_model([4 2]); Meas_info.S = normrnd(S,0.05*S);

%% Optional settings
options.modout = 'yes';                 % Return model (function) simulations of samples (yes/no)?
options.epsilon = 0.20*S;

%% Run the DREAM_ZS algorithm
[chain,output,fx,Z] = DREAM_ZS(Func_name,DREAMPar,Par_info,Meas_info,options);
