function [log_L] = HYDRUS(x)
% Runs the HYDRUS model and computes the log-likelihood

% Store local variable (is initally empty after declaration)
persistent fid data

% Only write the directory file (level_01.dir) one time
if isempty(fid),
    
    % Write level_01.dir (needed to execute HYDRUS-1D)
    fid = fopen('level_01.dir','w+'); fprintf(fid,'%s',pwd); fclose(fid);
    
    % Load structure with observations and data to help modify initial and boundary conditions
    data = Load_data;

end;

% Back-transform parameters
x(3:5) = 10.^x(3:5);

try

 	% Run HYDRUS-1D
	[ModPred] = runH1D(x,data);
	
	% Filter sims for measurement dates
	ind = zeros(size(data.hoy));
	for i = 1:size(data.hoy,1)
		ind(i) = find(ModPred.hoy == data.hoy(i));
	end

	% Compute number of measurements
	N = length(ModPred.water(ind));
	
	% Compute residuals
	epsilon = data.water - ModPred.water(ind);
	
	% Compute log-likelihood
	log_L = - (N/2) * log(sum(epsilon.^2));
	
catch	
	
	% If HYDRUS-1D did not converge, set the log-likelihood to some arbitrary low value
	log_L = -10^100;

end

log_L