% -------------------------------- Check the following paper ------------------------------ %
%                                                                                           %
%   Scharnagl, B., J.A. Vrugt, H. Vereecken, and M. Herbst (2011), Bayesian inverse         %
%	    modeling of soil water dynamics at the field scale: using prior information         %
%	    on soil hydraulic properties, Hydrology and Earth System Sciences, 15, 30433059,   %
%       doi:10.5194/hess-15-3043-2011.                                                      %
%                                                                                           %
% ----------------------------------------------------------------------------------------- %

%% Problem settings defined by user
DREAMPar.d = 7;                         % Dimension of the problem
DREAMPar.T = 2500;                      % Number of generations
DREAMPar.lik = 2;                       % Model output is log-likelihood

%% Provide information parameter space and initial sampling (use of informative multiplicative prior)
Par_info.initial = 'prior';             % Initial sample from prior distribution
Par_info.prior = { 'normpdf(0.0670,0.0060)','normpdf(0.4450,0.0090)','normpdf(-2.310,0.0600)',...
    'normpdf(0.2230,0.0110)','normpdf(-1.160,0.2700)','normpdf(0.3900,1.4700)','unifpdf(-250,-50)' };

%% Define feasible parameter space (minimum and maximum values)
% parname		[thetar	thetas	log10(alpha) log10(n) log10(Ks)	   L    h_bot
Par_info.boundhandling = 'reflect';     % Explicit boundary handling
Par_info.min =	[0.0430	0.4090	-2.5528		  0.1790  -2.2366	-5.4900	-250];  % For boundary handling
Par_info.max =	[0.0910 0.4810	-2.0706		  0.2670  -0.0800	 6.2700	-50];   % For boundary handling

%% Define name of function (.m file) for posterior exploration
Func_name = 'HYDRUS';

%% Optional settings
options.parallel = 'yes';              % Run chains in parallel
options.IO = 'yes';                    % Input-output writing of model files (for parallel setting only!)

%% Run the DREAM_ZS algorithm
[chain,output,fx,Z] = DREAM_ZS(Func_name,DREAMPar,Par_info,[],options);
